#! /bin/sh
##
# WiPal - A library and a set of tools to manipulate wireless traces.
# Copyright (C) 2007, 2008  Universite Pierre et Marie Curie - Paris 6
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA  02110-1301  USA
#
# Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
##


##
# This script is provided as a merging example.  It was used to merge
# CRAWDAD's uw/sigcomm2004 dataset [1], using all traces from channel
# 11.
#
# You need to put all the dataset's *-ath2 traces into the current
# working directory of this script before running it.  Change the
# following variables to setup the output directories.  Be sure to
# have enough free space on your drives.
#
# [1] http://crawdad.cs.dartmouth.edu/meta.php?name=uw/sigcomm2004
##

set -e

outputdir=/media/sdb1/claveiro
summarydir=merge-summary

run()
{
    summary=$summarydir/"$1"
    shift
    CMD="tt-windowed-merge -n -P $@"
    echo $CMD
    test "$SIMULATE_SYNC" || \
	/usr/bin/time -p -o "$summary".time $CMD \
	> "$summary".out 2> "$summary".err
}

sahara=sahara-ath2
chihuahuan=chihuahuan-ath2.00:chihuahuan-ath2.01:chihuahuan-ath2.02:chihuahuan-ath2.03:chihuahuan-ath2.04
kalahari=kalahari-ath2
mojave=mojave-ath2.00:mojave-ath2.01:mojave-ath2.02
sonoran=sonoran-ath2.00:sonoran-ath2.01:sonoran-ath2.02

kalahari_mojave=$outputdir/kalahari-mojave-ath2
sahara_chihuahuan=$outputdir/sahara-chihuahuan-ath2
sonoran_sahara_chihuahuan=$outputdir/sonoran-sahara-chihuahuan-ath2
kalahari_mojave_sonoran_sahara_chihuahuan=$outputdir/kalahari-mojave-sonoran-sahara-chihuahuan-ath2

run kalahari-mojave.merge \
	"$kalahari" "$mojave" "$kalahari_mojave"

run sahara-chihuahuan.merge \
	"$sahara" "$chihuahuan" "$sahara_chihuahuan"

run sonoran-sahara-chihuahuan.merge \
	"$sonoran" "$sahara_chihuahuan" "$sonoran_sahara_chihuahuan"

run kalahari-mojave-sonoran-sahara-chihuahuan.merge \
	"$kalahari_mojave" "$sonoran_sahara_chihuahuan" \
	"$kalahari_mojave_sonoran_sahara_chihuahuan"
