/*
 * WiPal - A library and a set of tools to manipulate wireless traces.
 * Copyright (C) 2007  Universite Pierre et Marie Curie - Paris 6
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 *
 * Author: Thomas Claveirole <thomas.claveirole@lip6.fr>
 */
#ifndef WIFI_FRAME_MGT_HH_
# define WIFI_FRAME_MGT_HH_

extern "C"
{
# include <inttypes.h>
}

# include <wipal/wifi/addr.hh>

namespace wifi
{

  namespace frame
  {

    /// IEEE 802.11 <i>management %frame</i> compounds.
    namespace mgt
    {

      /// IEEE 802.11 management %frame subtypes.
      namespace subtype
      {

	/// IEEE 802.11 management %frame subtypes.
	enum frame_subtype
	  {
	    assoc_req		= 0,  ///< Association request %subtype.
	    assoc_resp		= 1,  ///< Association response %subtype.
	    reassoc_req		= 2,  ///< Reassociation request %subtype.
	    reassoc_resp	= 3,  ///< Reassociation response %subtype.
	    probe_req		= 4,  ///< Probe request %subtype.
	    probe_resp		= 5,  ///< Probe response %subtype.
	    beacon		= 8,  ///< Beacon %frame %subtype.
	    atim		= 9,  ///< ATIM %frame %subtype.
	    disassoc		= 10, ///< Disassociation %frame %subtype.
	    auth		= 11, ///< Authentication %frame %subtype.
	    deauth		= 12  ///< De-authentication %frame %subtype.
	  };

      } // End of namespace wifi::frame::mgt::subtype.

      /// IEEE 802.11 management %frame structure.
      struct header
      {
	/// Frame addresses index.
	enum addr_index
	  {
	    da		= 0,	///< Destination address.
	    sa		= 1,	///< Source address.
	    bssid	= 2	///< BSSID address.
	  };

	/// Human readable representation of addresses' names.
	static const char*	addr_names[3];

	uint16_t		frame_ctl; ///< Frame control field.
	uint16_t		duration;  ///< Frame duration field.
	addr			addrs[3];  ///< Frame addresses.
	uint16_t		seq_ctl;   ///< Frame sequence control field.
	uint8_t			body[];    ///< Frame body.
      };

    } // End of namespace wifi::frame::mgt.

  } // End of namespace wifi::frame.

} // End of namespace wifi.

#endif // ! WIFI_FRAME_MGT_HH_
